@@ -83,5 +83,5 @@ class ConverterNode(Node):
         # NOTE not yet implemented
         pass
 
-    async def get_state(self):
+    def get_state(self):
         return State.Idle
